@@ -33,14 +33,15 @@
 #include "boot-settings.h"
 #include "table.h"
 
-#include "boot-image-editor.h"
 #include "boot-append-gui.h"
-#include "boot-append-editor.h"
 #include "boot-druid.h"
 
 extern GstTool *tool;
 extern GtkWidget *boot_table;
 
+gchar *initrd_label_str = N_("_Initrd image path:");
+gchar *module_label_str = N_("_Module path:");
+
 static GList *
 settings_dev_list (GstBootImageType ctype)
 {
@@ -73,6 +74,7 @@ on_type_entry_change (GtkWidget *w, gpointer data)
 	BootSettingsGui *gui;
 	const gchar *buf;
 	GstBootImageType type;
+	BootImage *image;
 
 	gui = (BootSettingsGui *) data;
 
@@ -81,8 +83,13 @@ on_type_entry_change (GtkWidget *w, gpointer data)
 	if (strlen (buf) > 0)
 	{
 		type = label_to_type (buf);
-		if (type == TYPE_LINUX)
+		if ((type == TYPE_LINUX) || (type == TYPE_HURD))
+		{
 			gtk_combo_set_popdown_strings (gui->root, settings_dev_list (type));
+			image = gui->image;
+			if (image->root)
+				gst_ui_entry_set_text (GTK_ENTRY (gui->root->entry), image->root);
+		}
 		else if (type != TYPE_LINSWAP)
 			gtk_combo_set_popdown_strings (gui->device, settings_dev_list (type));
 	}	
@@ -114,13 +121,13 @@ boot_settings_gui_new (BootImage *image, GtkWidget *parent)
 	gui->basic_frame = glade_xml_get_widget (gui->xml, "settings_basic_frame");
 	gui->name = GTK_ENTRY (glade_xml_get_widget (gui->xml, "settings_name"));
 	gui->type = GTK_COMBO (glade_xml_get_widget (gui->xml, "settings_type"));
-	/*gui->type_label = GTK_LABEL (glade_xml_get_widget (gui->xml, "boot_type_label"));*/
 
 	/* Image frame */
 	gui->image_frame = glade_xml_get_widget (gui->xml, "settings_image_frame");
 	gui->image_widget = glade_xml_get_widget (gui->xml, "settings_image");
 	gui->image_entry = GTK_ENTRY (glade_xml_get_widget (gui->xml, "settings_image_entry"));	
 	gui->root = GTK_COMBO (glade_xml_get_widget (gui->xml, "settings_root_combo"));
+	gui->initrd_label = glade_xml_get_widget (gui->xml, "settings_initrd_label");
 	gui->initrd_widget = glade_xml_get_widget (gui->xml, "settings_initrd");
 	gui->initrd_entry = GTK_ENTRY (glade_xml_get_widget (gui->xml, "settings_initrd_entry"));
 	gui->append = GTK_ENTRY (glade_xml_get_widget (gui->xml, "settings_append"));
@@ -130,6 +137,13 @@ boot_settings_gui_new (BootImage *image, GtkWidget *parent)
 	gui->other_frame = glade_xml_get_widget (gui->xml, "settings_other_frame");
 	gui->device = GTK_COMBO (glade_xml_get_widget (gui->xml, "settings_device"));
 
+	/* Security frame */
+	gui->use_password = GTK_CHECK_BUTTON (glade_xml_get_widget (gui->xml, "settings_use_password"));
+	gui->pass_label = GTK_LABEL (glade_xml_get_widget (gui->xml, "settings_pass_label"));
+	gui->confirm_label = GTK_LABEL (glade_xml_get_widget (gui->xml, "settings_confirm_label"));
+	gui->password = GTK_ENTRY (glade_xml_get_widget (gui->xml, "settings_password"));
+	gui->password_confirm = GTK_ENTRY (glade_xml_get_widget (gui->xml, "settings_password_confirm"));
+
 	/* Connect signals */
 	g_signal_connect (G_OBJECT (gui->name), "activate",
 			  G_CALLBACK (gui_grab_focus), (gpointer) gui->type->entry);
@@ -143,32 +157,30 @@ boot_settings_gui_new (BootImage *image, GtkWidget *parent)
 			  G_CALLBACK (gui_grab_focus), (gpointer) gui->append);
 	g_signal_connect (G_OBJECT (gui->append_browse), "clicked",
 	                  G_CALLBACK (on_boot_append_browse_clicked), (gpointer) gui);
+	g_signal_connect (G_OBJECT (gui->use_password), "clicked",
+			  G_CALLBACK (on_use_password_clicked), (gpointer) gui);
 
 	return gui;
 }
 
 static void
-setup_advanced (BootSettingsGui *gui, GtkWidget *parent)
+setup_gui (BootSettingsGui *gui, GtkWidget *parent)
 {
 	if (gui->image->type == TYPE_LINUX)
 	{
 		gtk_widget_show (gui->image_frame);
 		gtk_widget_hide (gui->other_frame);
-	}
-	else
-	{
-		gtk_widget_show (gui->other_frame);
-		gtk_widget_hide (gui->image_frame);
-	}
-}
 
-static void
-setup_basic (BootSettingsGui *gui, GtkWidget *parent)
-{
-	if (gui->image->type == TYPE_LINUX)
+		gtk_label_set_text (GTK_LABEL (gui->initrd_label), _(initrd_label_str));
+		gtk_label_set_use_underline (GTK_LABEL (gui->initrd_label), TRUE);
+	}
+	else if (gui->image->type == TYPE_HURD)
 	{
 		gtk_widget_show (gui->image_frame);
 		gtk_widget_hide (gui->other_frame);
+
+		gtk_label_set_text (GTK_LABEL (gui->initrd_label), _(module_label_str));
+		gtk_label_set_use_underline (GTK_LABEL (gui->initrd_label), TRUE);
 	}
 	else
 	{
@@ -222,7 +234,7 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 	{
 		gtk_combo_set_popdown_strings (gui->root, settings_dev_list (image->type));
 		if (image->root)
-		  gst_ui_entry_set_text (GTK_ENTRY (gui->root->entry), image->root);
+			gst_ui_entry_set_text (GTK_ENTRY (gui->root->entry), image->root);
 
 		if (error = boot_image_valid_initrd (image))
 			gst_ui_entry_set_text (gui->initrd_entry, "");
@@ -231,6 +243,19 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 
 		gst_ui_entry_set_text (gui->append, image->append);
 	}
+	else if (image->type == TYPE_HURD)
+	{
+		gtk_combo_set_popdown_strings (gui->root, settings_dev_list (image->type));
+		if (image->root)
+			gst_ui_entry_set_text (GTK_ENTRY (gui->root->entry), image->root);
+
+		if (error = boot_image_valid_module (image))
+			gst_ui_entry_set_text (gui->initrd_entry, "");
+		else
+			gst_ui_entry_set_text (gui->initrd_entry, image->module);
+
+		gst_ui_entry_set_text (gui->append, image->append);
+	}
 	else
 	{
 		gtk_combo_set_popdown_strings (gui->device, settings_dev_list (image->type));
@@ -248,27 +273,54 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 
 	gst_ui_entry_set_text (gui->device->entry, image->image);
 
-	if (!image->new) {
-		if (gst_dialog_get_complexity (tool->main_dialog) == GST_DIALOG_ADVANCED)
-			setup_advanced (gui, top);
-		if (gst_dialog_get_complexity (tool->main_dialog) == GST_DIALOG_BASIC)
-			setup_basic (gui, top);
+	if (image->password != NULL)
+	{
+		gst_ui_entry_set_text (gui->password, image->password);
+		gst_ui_entry_set_text (gui->password_confirm, image->password);
 	}
+	
+	if ((image->password == NULL) || (strlen (image->password) <= 0))
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gui->use_password),
+					      FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->password), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->password_confirm), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->pass_label), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->confirm_label), FALSE);
+	}
+	else
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gui->use_password),
+					      TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->password), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->password_confirm), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->pass_label), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gui->confirm_label), TRUE);
+	}
+	
+	if (!image->new)
+		setup_gui (gui, top);
 }
 
 gboolean
 boot_settings_gui_save (BootSettingsGui *gui, gboolean check)
-{	
+{
+	gchar *msg_error;
 	BootImage *image = gui->image;
 
-	if (image->label)  g_free (image->label);
-	if (image->image)  g_free (image->image);
-	if (image->root)   g_free (image->root);
-	if (image->initrd) g_free (image->initrd);
-	if (image->append) g_free (image->append);
+	if (image->label)    g_free (image->label);
+	if (image->image)    g_free (image->image);
+	if (image->root)     g_free (image->root);
+	if (image->initrd)   g_free (image->initrd);
+	if (image->append)   g_free (image->append);
+	if (image->password) g_free (image->password);
 
 	image->type = label_to_type (gtk_entry_get_text (GTK_ENTRY (gui->type->entry)));
-	image->label = g_strdup (gtk_entry_get_text (gui->name));	
+	image->label = g_strdup (gtk_entry_get_text (gui->name));
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gui->use_password)))
+		image->password = g_strdup (gtk_entry_get_text (gui->password));
+	else
+		image->password = g_strdup ("");
 
 	if (image->type == TYPE_LINUX)
 	{
@@ -277,6 +329,13 @@ boot_settings_gui_save (BootSettingsGui *gui, gboolean check)
 		image->image = g_strdup (gtk_entry_get_text (gui->image_entry));
 		image->initrd = g_strdup (gtk_entry_get_text (gui->initrd_entry));
 	}
+	else if (image->type == TYPE_HURD)
+	{
+		image->root = g_strdup (gtk_entry_get_text (GTK_ENTRY (gui->root->entry)));
+		image->append = g_strdup (gtk_entry_get_text (gui->append));
+		image->image = g_strdup (gtk_entry_get_text (gui->image_entry));
+		image->module = g_strdup (gtk_entry_get_text (gui->initrd_entry));
+	}
 	else
 	{
 		image->root = g_strdup ("");
@@ -285,14 +344,25 @@ boot_settings_gui_save (BootSettingsGui *gui, gboolean check)
 		image->initrd = g_strdup ("");
 	}
 
-	if (check) {
-		gchar *error = boot_image_check (image);
-		if (error) {
-			boot_settings_gui_error (GTK_WINDOW (gui->top), error);
+	if (check)
+	{
+		msg_error = boot_image_check (image);
+
+		if (msg_error)
+		{
+			boot_settings_gui_error (GTK_WINDOW (gui->top), msg_error);
+			return FALSE;
+		}
+
+		if (strcmp (gtk_entry_get_text (gui->password),
+			    gtk_entry_get_text (gui->password_confirm)) != 0)
+		{
+			msg_error = g_strdup (_("Password confirmation isn't correct."));
+			boot_settings_gui_error (GTK_WINDOW (gui->top), msg_error);
 			return FALSE;
 		}
 	}
-	
+
 	boot_table_update ();
 	gst_dialog_modify (tool->main_dialog);
 
