@@ -738,6 +738,109 @@ connection_list_update (void)
 	}
 }
 
+/* Polls the backend and updates the active interfaces */
+gboolean
+connection_poll_stat (GstTool *tool)
+{
+	gchar *dev;
+	gboolean enabled, found, valid;
+	GstConnection *cxn;
+	xmlDoc *doc;
+	xmlNodePtr root, node;
+	GtkWidget *ifaces_list;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	/* if the tool is running remotely, we don't want this function to be run */
+	if (tool->remote_config)
+		return FALSE;
+
+	doc = gst_tool_run_get_directive (tool, NULL, "list_ifaces", NULL);
+
+	/* couldn't access the backend, return safely */
+	if (!doc)
+		return TRUE;
+	
+	root = gst_xml_doc_get_root (doc);
+
+	ifaces_list = gst_dialog_get_widget (tool->main_dialog, "connection_list");
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ifaces_list));
+	valid = gtk_tree_model_get_iter_first (model, &iter);
+		
+	while (valid) {
+		gtk_tree_model_get (model, &iter, CONNECTION_LIST_COL_DATA, &cxn, -1);
+		node = gst_xml_element_find_first (root, "interface");
+		found = FALSE;
+
+		while (!found && node) {
+			dev = gst_xml_get_child_content (node, "dev");
+
+			if (strcmp (cxn->dev, dev) == 0) {
+				found = TRUE;
+				enabled = gst_xml_element_get_boolean (node, "active");
+			}
+
+			node = gst_xml_element_find_next (node, "interface");
+			g_free (dev);
+			}
+
+		/* the interface might be activating/deactivating during the poll
+		   in this case we shouldn't change the state */
+		if ((found) && (cxn->activation == ACTIVATION_NONE))
+			cxn->enabled = enabled;
+		else if (!found)
+			cxn->enabled = FALSE;
+		
+		cxn->activation = ACTIVATION_NONE;
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+				    CONNECTION_LIST_COL_STAT, cxn->enabled, -1);
+
+		valid = gtk_tree_model_iter_next (model, &iter);
+	}
+
+	gst_xml_doc_destroy (doc);
+	
+	return TRUE;
+}
+
+static void
+activate_directive_cb (GstDirectiveEntry *entry)
+{
+	gchar *file = entry->data;
+
+	gst_tool_run_set_directive (entry->tool, entry->in_xml, entry->report_sign, entry->directive,
+				    file, "1", NULL);
+	g_free (entry->report_sign);
+}
+
+static void
+deactivate_directive_cb (GstDirectiveEntry *entry)
+{
+	gchar *file = entry->data;
+	
+	gst_tool_run_set_directive (entry->tool, entry->in_xml, entry->report_sign, entry->directive,
+				    file, "0", NULL);
+	g_free (entry->report_sign);
+}
+
+void
+connection_enable (GstConnection *cxn, gboolean enable)
+{
+	gchar *file;
+	
+	file = (cxn->file)? cxn->file: cxn->dev;
+
+	if (enable) {
+		gst_tool_queue_directive (tool, activate_directive_cb, file, NULL, NULL, "enable_iface");
+		cxn->activation = ACTIVATION_UP;
+	} else {
+		gst_tool_queue_directive (tool, deactivate_directive_cb, file, NULL, NULL, "enable_iface");
+		cxn->activation = ACTIVATION_DOWN;
+	}
+	
+	connection_show_activated (cxn, enable);
+}
+
 GstConnection *
 connection_find_by_dev (GtkWidget *list, gchar *dev)
 {
@@ -1147,7 +1250,7 @@ connection_default_gw_set_auto (GstTool *tool)
 }
 
 void
-connection_activate (GstConnection *cxn, gboolean activate)
+connection_show_activated (GstConnection *cxn, gboolean activate)
 {
 	g_return_if_fail (cxn != NULL);
 
@@ -1168,60 +1271,6 @@ connection_add_to_list (GstConnection *cxn)
 	connection_default_gw_add (cxn);
 }
 
-static void
-connection_update_complexity_advanced (GstTool *tool)
-{
-	GstConnection   *cxn;
-	GstConnectionUI *ui;
-	GtkTreeModel    *model;
-
-	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->list));
-
-	cxn = g_object_steal_data (G_OBJECT (model), "lo");
-	if (cxn)
-		connection_add_to_list (cxn);
-}
-
-static gboolean
-update_complexity_basic_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-	GstConnection *cxn;
-
-	gtk_tree_model_get (model, iter, CONNECTION_LIST_COL_DATA, &cxn, -1);
-	if (cxn->type == GST_CONNECTION_LO) {
-		g_object_set_data (G_OBJECT (model), "lo", cxn);
-		gtk_list_store_remove (GTK_LIST_STORE (model), iter);
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
-static void
-connection_update_complexity_basic (GstTool *tool)
-{
-	GstConnectionUI *ui;
-	GtkTreeModel    *model;
-
-	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->list));
-
-	gtk_tree_model_foreach (model, update_complexity_basic_cb, NULL);
-}
-
-void
-connection_update_complexity (GstTool *tool, GstDialogComplexity complexity)
-{
-	switch (complexity) {
-	case GST_DIALOG_BASIC:
-		connection_update_complexity_basic (tool);
-		break;
-	case GST_DIALOG_ADVANCED:
-		connection_update_complexity_advanced (tool);
-	}
-}
-
 static gchar *
 connection_description_from_type (GstConnectionType type)
 {
@@ -1334,7 +1383,6 @@ connection_new_from_type (GstConnectionType type, xmlNode *root)
 	cxn->file = NULL;
 
 	cxn->activation = ACTIVATION_NONE;
-	cxn->bulb_state = FALSE;
 	
 	/* set up some defaults */
 	cxn->user = FALSE;
@@ -1656,24 +1704,33 @@ connection_validate (GstConnection *cxn)
 		if (cxn->ip_config == IP_MANUAL &&
 		    (strempty (cxn->address) ||
 		     strempty (cxn->netmask)))
-			error = _("The IP address or netmask for the interface\n"
-				  "was left empty. Please enter valid IP\n"
+			error = _("The IP address or netmask for the interface "
+				  "was left empty. Please enter valid IP "
 				  "addresses in those fields to continue.");
 		break;
 	case GST_CONNECTION_PLIP:
 		if (strempty (cxn->address) ||
 		    strempty (cxn->remote_address))
-			error = _("The IP address or remote address for the\n"
-				  "interface was left empty. Please enter valid\n"
+			error = _("The IP address or remote address for the "
+				  "interface was left empty. Please enter valid "
 				  "IP addresses in those fields to continue.");
 		break;
 	case GST_CONNECTION_PPP:
 		if (!cxn->update_dns && strempty (cxn->dns1))
-			error = _("You chose to set the DNS servers for this\n"
-				  "connection manually, but left the IP\n"
-				  "address for the primary DNS empty. Please\n"
-				  "enter the IP for the primary DNS or uncheck\n"
+			error = _("You chose to set the DNS servers for this "
+				  "connection manually, but left the IP "
+				  "address for the primary DNS empty. Please "
+				  "enter the IP for the primary DNS or uncheck "
 				  "the manual DNS option.");
+		else if (strempty (cxn->serial_port))
+			error = _("The modem device that the connection "
+				  "will use was left empty. Please enter "
+				  "a device or press \"autodetect\" to "
+				  "continue.");
+		else if (strempty (cxn->phone_number))
+			error = _("The phone number that the connection "
+				  "will use was left empty. Please enter "
+				  "a valid phone number to continue.");
 		break;
 	default:
 		break;
@@ -1960,16 +2017,13 @@ connection_actions_set_sensitive (gboolean state)
 	gchar *names[] = {
 		"connection_delete",
 		"connection_configure",
+		"connection_activate",
+		"connection_deactivate",
 		NULL
 	};
 
 	for (i = 0; names[i]; i++)
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, names[i], state);
-	
-	if (state == FALSE)
-	{
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "connection_configure", TRUE);
-	}
+		gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, names[i]), state);
 }
 
 void
@@ -2236,7 +2290,7 @@ gchar*
 connection_autodetect_modem (void)
 {
 	xmlNodePtr root;
-	xmlDoc *doc = gst_tool_run_get_directive (tool, _("Autodetecting modem device"), "detect_modem", NULL);
+	xmlDoc *doc = gst_tool_run_get_directive (tool, NULL, "detect_modem", NULL);
 	GtkWidget *w;
 
 	g_return_val_if_fail (doc != NULL, NULL);
