@@ -24,7 +24,7 @@
 #ifndef _TABLE_H
 #define _TABLE_H
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 enum {
 	COL_ACTIVE,
@@ -33,6 +33,10 @@ enum {
 	COL_LAST
 };
 
+enum {
+	POPUP_SETTINGS
+};
+
 void			table_create				(void);
 void			table_populate				(xmlNodePtr, gint);
 void                    table_empty                             (void);
